# coding: utf-8

"""
    authentik

    Making authentication simple.

    The version of the OpenAPI document: 2025.10.0-rc1
    Contact: hello@goauthentik.io
    Generated by OpenAPI Generator (https://openapi-generator.tech)

    Do not edit the class manually.
"""  # noqa: E501


import unittest

from authentik_client.models.patched_saml_source_request import PatchedSAMLSourceRequest

class TestPatchedSAMLSourceRequest(unittest.TestCase):
    """PatchedSAMLSourceRequest unit test stubs"""

    def setUp(self):
        pass

    def tearDown(self):
        pass

    def make_instance(self, include_optional) -> PatchedSAMLSourceRequest:
        """Test PatchedSAMLSourceRequest
            include_optional is a boolean, when False only required
            params are included, when True both required and
            optional params are included """
        # uncomment below to create an instance of `PatchedSAMLSourceRequest`
        """
        model = PatchedSAMLSourceRequest()
        if include_optional:
            return PatchedSAMLSourceRequest(
                name = '0',
                slug = 'z0',
                enabled = True,
                authentication_flow = '',
                enrollment_flow = '',
                user_property_mappings = [
                    ''
                    ],
                group_property_mappings = [
                    ''
                    ],
                policy_engine_mode = 'all',
                user_matching_mode = 'identifier',
                user_path_template = '0',
                group_matching_mode = 'identifier',
                pre_authentication_flow = '',
                issuer = '',
                sso_url = '0',
                slo_url = '',
                allow_idp_initiated = True,
                name_id_policy = 'urn:oasis:names:tc:SAML:1.1:nameid-format:emailAddress',
                binding_type = 'REDIRECT',
                verification_kp = '',
                signing_kp = '',
                digest_algorithm = 'http://www.w3.org/2000/09/xmldsig#sha1',
                signature_algorithm = 'http://www.w3.org/2000/09/xmldsig#rsa-sha1',
                temporary_user_delete_after = '0',
                encryption_kp = '',
                signed_assertion = True,
                signed_response = True
            )
        else:
            return PatchedSAMLSourceRequest(
        )
        """

    def testPatchedSAMLSourceRequest(self):
        """Test PatchedSAMLSourceRequest"""
        # inst_req_only = self.make_instance(include_optional=False)
        # inst_req_and_optional = self.make_instance(include_optional=True)

if __name__ == '__main__':
    unittest.main()
